@@ -38,6 +38,9 @@
 #ifndef SYS_PIDFILE
 #define SYS_PIDFILE "/var/run/alsactl.pid"
 #endif
+#ifndef SYS_LOCKPATH
+#define SYS_LOCKPATH "/var/lock"
+#endif
 
 int debugflag = 0;
 int force_restore = 1;
@@ -46,6 +49,7 @@ int do_lock = 0;
 int use_syslog = 0;
 char *command;
 char *statefile = NULL;
+char *lockfile = SYS_LOCKFILE;
 
 #define TITLE	0x0100
 #define HEADER	0x0200
@@ -71,6 +75,8 @@ static struct arg args[] = {
 { HEADER, NULL, "Available state options:" },
 { FILEARG | 'f', "file", "configuration file (default " SYS_ASOUNDRC ")" },
 { 'l', "lock", "use file locking to serialize concurrent access" },
+{ 'L', "no-lock", "do not use file locking to serialize concurrent access" },
+{ FILEARG | 'O', "lock-state-file", "state lock file path (default " SYS_LOCKFILE ")" },
 { 'F', "force", "try to restore the matching controls as much as possible" },
 { 0, NULL, "  (default mode)" },
 { 'g', "ignore", "ignore 'No soundcards found' error" },
@@ -100,6 +106,7 @@ static struct arg args[] = {
 { CARDCMD, "daemon", "store state periodically for one or each soundcards" },
 { CARDCMD, "rdaemon", "like daemon but do the state restore at first" },
 { KILLCMD, "kill", "notify daemon to quit, rescan or save_and_quit" },
+{ CARDCMD, "monitor", "monitor control events" },
 { 0, NULL, NULL }
 };
 
@@ -231,6 +238,12 @@ int main(int argc, char *argv[])
 		case 'l':
 			do_lock = 1;
 			break;
+		case 'L':
+			do_lock = -1;
+			break;
+		case 'O':
+			lockfile = optarg;
+			break;
 		case 'F':
 			force_restore = 1;
 			break;
@@ -323,7 +336,7 @@ int main(int argc, char *argv[])
 	}
 
 	/* the global system file should be always locked */
-	if (strcmp(cfgfile, SYS_ASOUNDRC) == 0)
+	if (strcmp(cfgfile, SYS_ASOUNDRC) == 0 && do_lock >= 0)
 		do_lock = 1;
 
 	/* when running in background, use syslog for reports */
@@ -363,6 +376,8 @@ int main(int argc, char *argv[])
 		res = state_daemon(cfgfile, cardname, period, pidfile);
 	} else if (!strcmp(cmd, "kill")) {
 		res = state_daemon_kill(pidfile, cardname);
+	} else if (!strcmp(cmd, "monitor")) {
+		res = monitor(cardname);
 	} else {
 		fprintf(stderr, "alsactl: Unknown command '%s'...\n", cmd);
 		res = -ENODEV;
